@@ -31,6 +31,8 @@ typedef struct {
 
 typedef struct _SecretSession SecretSession;
 
+#define              SECRET_ALIAS_PREFIX                      "/org/freedesktop/secrets/aliases/"
+
 #define              SECRET_SERVICE_PATH                      "/org/freedesktop/secrets"
 
 #define              SECRET_SERVICE_BUS_NAME                  "org.freedesktop.secrets"
@@ -63,6 +65,9 @@ SecretPrompt *       _secret_prompt_instance                  (SecretService *se
 
 void                 _secret_util_strip_remote_error          (GError **error);
 
+gboolean             _secret_util_propagate_error             (GSimpleAsyncResult *async,
+                                                               GError **error);
+
 gchar *              _secret_util_parent_path                 (const gchar *path);
 
 gboolean             _secret_util_empty_path                  (const gchar *path);
@@ -166,6 +171,11 @@ gint                 _secret_service_xlock_paths_finish       (SecretService *se
                                                                gchar ***xlocked,
                                                                GError **error);
 
+void                 _secret_service_create_item_dbus_path_finish_raw  (GAsyncResult *result,
+                                                                        GError **error);
+
+GHashTable *         _secret_collection_properties_new        (const gchar *label);
+
 SecretItem *         _secret_collection_find_item_instance    (SecretCollection *self,
                                                                const gchar *item_path);
 
