@@ -17,7 +17,6 @@
 
 #include "secret-collection.h"
 #include "secret-dbus-generated.h"
-#include "secret-enum-types.h"
 #include "secret-item.h"
 #include "secret-paths.h"
 #include "secret-private.h"
@@ -25,6 +24,8 @@
 #include "secret-types.h"
 #include "secret-value.h"
 
+#include "libsecret/secret-enum-types.h"
+
 #include "egg/egg-secure-memory.h"
 
 /**
@@ -66,10 +67,7 @@
  * In order to customize prompt handling, override the <literal>prompt_async</literal>
  * and <literal>prompt_finish</literal> virtual methods of the #SecretService class.
  *
- * These functions have an unstable API and may change across versions. Use
- * <literal>libsecret-unstable</literal> package to access them.
- *
- * Stability: Unstable
+ * Stability: Stable
  */
 
 /**
@@ -88,6 +86,10 @@
  * @prompt_async: called to perform asynchronous prompting when necessary
  * @prompt_finish: called to complete an asynchronous prompt operation
  * @prompt_sync: called to perform synchronous prompting when necessary
+ * @get_collection_gtype: called to get the GObject type for collections
+ *                        instantiated by the #SecretService proxy
+ * @get_item_gtype: called to get the GObject type for collections
+ *                  instantiated by the #SecretService proxy
  *
  * The class for #SecretService.
  */
@@ -201,7 +203,7 @@ service_cache_instance (SecretService *instance)
 	proxy = G_DBUS_PROXY (instance);
 	watch = g_bus_watch_name_on_connection (g_dbus_proxy_get_connection (proxy),
 	                                        g_dbus_proxy_get_name (proxy),
-	                                        G_BUS_NAME_WATCHER_FLAGS_AUTO_START,
+	                                        G_BUS_NAME_WATCHER_FLAGS_NONE,
 	                                        NULL, on_service_instance_vanished,
 	                                        instance, NULL);
 
@@ -300,7 +302,7 @@ secret_service_real_prompt_sync (SecretService *self,
                                  const GVariantType *return_type,
                                  GError **error)
 {
-	return secret_prompt_perform_sync (prompt, 0, cancellable, return_type, error);
+	return secret_prompt_perform_sync (prompt, NULL, cancellable, return_type, error);
 }
 
 static void
@@ -1097,7 +1099,7 @@ secret_service_get_flags (SecretService *self)
  * initializing #SecretService proxy object, then this method will return
  * %NULL. Use secret_service_load_collections() to load the collections.
  *
- * Returns: (transfer full) (element-type SecretUnstable.Collection) (allow-none): a
+ * Returns: (transfer full) (element-type Secret.Collection) (allow-none): a
  *          list of the collections in the secret service
  */
 GList *
@@ -1646,7 +1648,7 @@ secret_service_load_collections_sync (SecretService *self,
  *
  * Override the #SecretServiceClass <literal>prompt_sync</literal> virtual method
  * to change the behavior of the propmting. The default behavior is to simply
- * run secret_prompt_perform_sync() on the prompt.
+ * run secret_prompt_perform_sync() on the prompt with a %NULL <literal>window_id</literal>.
  *
  * Returns: (transfer full): %NULL if the prompt was dismissed or an error occurred,
  *          a variant result if the prompt was successful
@@ -1771,9 +1773,9 @@ secret_service_get_collection_gtype (SecretService *self)
 
 /**
  * secret_service_get_item_gtype:
- * @self: the collection
+ * @self: the service
  *
- * Get the GObject type for items instantiated by this collection.
+ * Get the GObject type for items instantiated by this service.
  * This will always be either #SecretItem or derived from it.
  *
  * Returns: the gobject type for items
